# pytest-django-queries
Generate performance rapports from your django database performance tests.

## Integrating with GitHub

## Testing locally
Simply install `pytest-django-queries` through pip and run your 
tests using `pytest`. A report should have been generated in your
current working directory in a JSON file prefixed with `.pytest-queries`.

Note: to override the save path, set the `PYTEST_QUERIES_SAVE_PATH`
environment variable to any given valid path.

## Visualising Results

## Comparing results
